netapp_ontap.models.security_association_ike API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_association_ike`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityAssociationIkeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityAssociationIke object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `authentication: str GET POST PATCH`

    Authentication method for internet key exchange protocol.

    Valid choices:

    - none
    - psk
    - cert
  `initiator_security_parameter_index: str GET POST PATCH`

    Initiator's security parameter index for the IKE security association.

  `is_initiator: bool GET POST PATCH`

    Indicates whether or not IKE has been initiated by this node.

  `responder_security_parameter_index: str GET POST PATCH`

    Responder's security parameter index for the IKE security association.

  `state: str GET POST PATCH`

    State of the IKE connection.

    Valid choices:

    - none
    - connecting
    - established
    - dead_peer_probe
  `version: Size GET POST PATCH`

    Internet key exchange protocol version.